.. _pipeline_api:

Pipeline
================================

.. automodule:: imbalanced_ensemble.pipeline
    :no-members:
    :no-inherited-members:

.. currentmodule:: imbalanced_ensemble.pipeline

.. autosummary::
   :toctree: _autosummary
   :template: class.rst

   Pipeline

.. autosummary::
   :toctree: _autosummary
   :template: function.rst

   make_pipeline